@@ -1,10 +1,11 @@
 from functools import wraps
+import warnings
 
-from list_ import iterate_items
+from .list_ import iterate_items
 
 
 __all__ = [
-    'memoized', 'memoized_property', 'assert_hashable',
+    'memoized', 'memoized_property', 'assert_hashable', 'deprecated',
 ]
 
 
@@ -47,7 +48,7 @@ def memoized(fn=None, cache=None):
 
         >>> @memoized
         ... def foo(bar):
-        ...   print "Not cached."
+        ...   print("Not cached.")
         >>> foo(1)
         Not cached.
         >>> foo(1)
@@ -62,7 +63,7 @@ def memoized(fn=None, cache=None):
         >>> lru_container = RecentlyUsedContainer(maxsize=2)
         >>> @memoized(cache=lru_container)
         ... def baz(x):
-        ...   print "Not cached."
+        ...   print("Not cached.")
         >>> baz(1)
         Not cached.
         >>> baz(1)
@@ -90,7 +91,7 @@ def memoized(fn=None, cache=None):
 
             try:
                 is_cached = key in cache
-            except TypeError, e:
+            except TypeError as e:
                 # Re-raise a more descriptive error if it's a hashing problem.
                 assert_hashable(*args, **kw)
                 # If it hasn't raised by now, then something else is going on,
@@ -123,6 +124,39 @@ class memoized_property(object):
         return result
 
 
+def deprecated(message, exception=PendingDeprecationWarning):
+    """Throw a warning when a function/method will be soon deprecated
+
+    Supports passing a ``message`` and an ``exception`` class
+    (uses ``PendingDeprecationWarning`` by default). This is useful if you
+    want to alternatively pass a ``DeprecationWarning`` exception for already
+    deprecated functions/methods.
+
+    Example::
+
+        >>> import warnings
+        >>> from functools import wraps
+        >>> message = "this function will be deprecated in the near future"
+        >>> @deprecated(message)
+        ... def foo(n):
+        ...     return n+n
+        >>> with warnings.catch_warnings(record=True) as w:
+        ...     warnings.simplefilter("always")
+        ...     foo(4)
+        ...     assert len(w) == 1
+        ...     assert issubclass(w[-1].category, PendingDeprecationWarning)
+        ...     assert message == str(w[-1].message)
+        8
+    """
+    def decorator(func):
+        wraps(func)
+        def wrapper(*args, **kwargs):
+            warnings.warn(message, exception, stacklevel=2)
+            return func(*args, **kwargs)
+        return wrapper
+    return decorator
+
+
 if __name__ == "__main__":
     import doctest
     doctest.testmod(optionflags=doctest.ELLIPSIS)
